@@ -111,8 +111,10 @@ QStringList Collection::contentMimeTypes() const
 void Collection::setContentMimeTypes( const QStringList & types )
 {
   Q_D( Collection );
-  d->contentTypes = types;
-  d->contentTypesChanged = true;
+  if ( d->contentTypes != types ) {
+    d->contentTypes = types;
+    d->contentTypesChanged = true;
+  }
 }
 
 Collection::Id Collection::parent() const
@@ -228,4 +230,10 @@ void Collection::setCachePolicy(const CachePolicy & cachePolicy)
   d->cachePolicyChanged = true;
 }
 
+bool Collection::isVirtual() const
+{
+  // TODO make this a proper flag
+  return ( (resource() == QLatin1String( "akonadi_search_resource" ) || resource() == QLatin1String( "akonadi_nepomuktag_resource" ) ) );
+}
+
 AKONADI_DEFINE_PRIVATE( Akonadi::Collection )
