@@ -21,6 +21,9 @@
 #define AKONADI_COLLECTIONUTILS_P_H
 
 #include <QtCore/QStringList>
+#include <akonadi/entitydisplayattribute.h>
+#include <akonadi/collectionstatistics.h>
+#include <akonadi/item.h>
 
 namespace Akonadi {
 
@@ -31,18 +34,28 @@ namespace CollectionUtils
 {
   inline bool isVirtualParent( const Collection &collection )
   {
-    return (collection.parent() == Collection::root().id() &&
-            collection.resource() == QLatin1String( "akonadi_search_resource" ));
+    return (collection.parentCollection() == Collection::root() &&
+            ( collection.resource() == QLatin1String( "akonadi_search_resource" ) || collection.resource() == QLatin1String( "akonadi_nepomuktag_resource" ) ) );
   }
 
   inline bool isVirtual( const Collection &collection )
   {
-    return (collection.resource() == QLatin1String( "akonadi_search_resource" ));
+    return ( (collection.resource() == QLatin1String( "akonadi_search_resource" ) || collection.resource() == QLatin1String( "akonadi_nepomuktag_resource" ) ) );
+  }
+
+  inline bool isReadOnly( const Collection &collection )
+  {
+    return !(collection.rights() & Collection::CanCreateItem);
+  }
+
+  inline bool isRoot( const Collection &collection )
+  {
+    return (collection == Collection::root());
   }
 
   inline bool isResource( const Collection &collection )
   {
-    return (collection.parent() == Collection::root().id());
+    return (collection.parentCollection() == Collection::root());
   }
 
   inline bool isStructural( const Collection &collection )
@@ -52,9 +65,11 @@ namespace CollectionUtils
 
   inline bool isFolder( const Collection &collection )
   {
-    return (collection.parent() != Collection::root().id() &&
+    return (!isRoot( collection ) &&
+            !isResource( collection ) &&
+            !isStructural( collection ) &&
             collection.resource() != QLatin1String( "akonadi_search_resource" ) &&
-            !collection.contentMimeTypes().isEmpty());
+            collection.resource() != QLatin1String( "akonadi_nepomuktag_resource" ));
   }
 
   inline QString defaultIconName( const Collection &col )
@@ -67,6 +82,8 @@ namespace CollectionUtils
       return QLatin1String( "network-server" );
     if ( CollectionUtils::isStructural( col ) )
       return QLatin1String( "folder-grey" );
+    if ( CollectionUtils::isReadOnly( col ) )
+      return QLatin1String( "folder-grey" );
 
     const QStringList content = col.contentMimeTypes();
     if ( content.size() == 1 || (content.size() == 2 && content.contains( Collection::mimeType() )) ) {
@@ -83,6 +100,32 @@ namespace CollectionUtils
     }
     return QLatin1String( "folder" );
   }
+  inline QString displayIconName( const Collection &col )
+  {
+    QString iconName = defaultIconName( col );
+    if ( col.hasAttribute<EntityDisplayAttribute>() &&
+         !col.attribute<EntityDisplayAttribute>()->iconName().isEmpty() ) {
+      if ( !col.attribute<EntityDisplayAttribute>()->activeIconName().isEmpty() && col.statistics().unreadCount()> 0) {
+        iconName = col.attribute<EntityDisplayAttribute>()->activeIconName();
+      }
+      else
+        iconName = col.attribute<EntityDisplayAttribute>()->iconName();
+      }
+    return iconName;
+
+  }
+  inline bool hasValidHierarchicalRID( const Collection &col )
+  {
+    if ( col == Collection::root() )
+      return true;
+    if ( col.remoteId().isEmpty() )
+      return false;
+    return hasValidHierarchicalRID( col.parentCollection() );
+  }
+  inline bool hasValidHierarchicalRID( const Item &item )
+  {
+    return !item.remoteId().isEmpty() && hasValidHierarchicalRID( item.parentCollection() );
+  }
 }
 
 }
