@@ -92,7 +92,10 @@ bool EntityTreeModel::includeUnsubscribed() const
 void EntityTreeModel::setIncludeUnsubscribed( bool show )
 {
   Q_D( EntityTreeModel );
+  d->beginResetModel();
   d->m_includeUnsubscribed = show;
+  d->m_monitor->setAllMonitored( show );
+  d->endResetModel();
 }
 
 
@@ -135,7 +138,9 @@ QVariant EntityTreeModel::entityData( const Item &item, int column, int role ) c
              !item.attribute<EntityDisplayAttribute>()->displayName().isEmpty() ) {
           return item.attribute<EntityDisplayAttribute>()->displayName();
         } else {
-          return item.remoteId();
+          if (!item.remoteId().isEmpty())
+            return item.remoteId();
+          return QLatin1String("<") + QString::number( item.id() ) + QLatin1String(">");
         }
         break;
       case Qt::DecorationRole:
@@ -175,7 +180,9 @@ QVariant EntityTreeModel::entityData( const Collection &collection, int column,
              !collection.attribute<EntityDisplayAttribute>()->displayName().isEmpty() ) {
           return collection.attribute<EntityDisplayAttribute>()->displayName();
         }
-        return collection.name();
+        if ( !collection.name().isEmpty() )
+          return collection.name();
+        return QString::fromLatin1( "Loading ..." );
       }
       break;
     case Qt::DecorationRole:
@@ -253,10 +260,14 @@ QVariant EntityTreeModel::data( const QModelIndex & index, int role ) const
         CollectionStatistics statistics = collection.statistics();
         return statistics.unreadCount();
       }
-      case FetchStateRole :
+      case FetchStateRole:
       {
         return d->m_pendingCollectionRetrieveJobs.contains(collection.id()) ? FetchingState : IdleState;
       }
+      case CollectionSyncProgressRole:
+      {
+        return d->m_collectionSyncProgress.value( collection.id() );
+      }
       case Qt::BackgroundRole:
       {
         if ( collection.hasAttribute<EntityDisplayAttribute>() )
@@ -474,7 +485,7 @@ bool EntityTreeModel::dropMimeData( const QMimeData * data, Qt::DropAction actio
       foreach ( const KUrl &url, urls ) {
         const Collection collection = d->m_collections.value( Collection::fromUrl( url ).id() );
         if ( collection.isValid() ) {
-          if ( collection.parentCollection().id() == destCollection.id() ) {
+          if ( collection.parentCollection().id() == destCollection.id() && action != Qt::CopyAction) {
             kDebug() << "Error: source and destination of move are the same.";
             return false;
           }
@@ -486,7 +497,7 @@ bool EntityTreeModel::dropMimeData( const QMimeData * data, Qt::DropAction actio
         } else {
           const Item item = d->m_items.value( Item::fromUrl( url ).id() );
           if ( item.isValid() ) {
-            if ( item.parentCollection().id() == destCollection.id() ) {
+            if ( item.parentCollection().id() == destCollection.id() && action != Qt::CopyAction ) {
               kDebug() << "Error: source and destination of move are the same.";
               return false;
             }
