@@ -40,6 +40,24 @@ class Session;
  * The Monitor emits signals if some of these objects are changed or
  * removed or new ones are added to the Akonadi storage.
  *
+ * There are various ways to filter these notifications. There are three types of filter
+ * evaluation:
+ * - (-) removal-only filter, ie. if the filter matches the notification is dropped,
+ *   if not filter evaluation continues with the next one
+ * - (+) pass-exit filter, ie. if the filter matches the notification is delivered,
+ *   if not evaluation is continued
+ * - (f) final filter, ie. evaluation ends here if the corresponding filter criteria is set,
+ *   the notification is delievered depending on the result, evaluation is only continued
+ *   if no filter criteria is defined
+ *
+ * The following filter are available, listed in evaluation order:
+ * (1) ignored sessions (-)
+ * (2) monitor everything (+)
+ * (3a) resource and mimetype filters (f) (items only)
+ * (3b) resource filters (f) (collections only)
+ * (4) item is monitored (+)
+ * (5) collection is monitored (+)
+ * 
  * Optionally, the changed objects can be fetched automatically from the server.
  * To enable this, see itemFetchScope() and collectionFetchScope().
  *
@@ -217,8 +235,19 @@ class AKONADI_EXPORT Monitor : public QObject
      * Returns the set of items being monitored.
      *
      * @since 4.3
+     *
+     * @deprecated Use itemsMonitoredEx() instead.
      */
-    QList<Item::Id> itemsMonitored() const;
+    KDE_DEPRECATED QList<Item::Id> itemsMonitored() const;
+
+    /**
+     * Returns the set of items being monitored.
+     *
+     * Faster version (at least on 32-bit systems) of itemsMonitored().
+     *
+     * @since 4.6
+     */
+    QVector<Item::Id> itemsMonitoredEx() const;
 
     /**
      * Returns the set of mimetypes being monitored.
@@ -354,6 +383,27 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void collectionRemoved( const Akonadi::Collection &collection );
 
+    /**
+     * This signal is emitted if a collection has been subscribed to by the user.
+     *  It will be emitted even for unmonitored collections as the check for whether to
+     *  monitor it has not been applied yet.
+     *
+     * @param collection The subscribed collection
+     * @param parent The parent collection of the subscribed collection.
+     *
+     * @since 4.6
+     */
+    void collectionSubscribed( const Akonadi::Collection& collection, const Akonadi::Collection &parent  );
+
+    /**
+     * This signal is emitted if a user unsubscribes from a collection.
+     *
+     * @param collection The unsubscribed collection
+     *
+     * @since 4.6
+     */
+    void collectionUnsubscribed( const Akonadi::Collection& collection );
+
     /**
      * This signal is emitted if the statistics information of a monitored collection
      * has changed.
@@ -426,6 +476,7 @@ class AKONADI_EXPORT Monitor : public QObject
     Q_PRIVATE_SLOT( d_ptr, void slotFlushRecentlyChangedCollections() )
     Q_PRIVATE_SLOT( d_ptr, void slotNotify( const Akonadi::NotificationMessage::List& ) )
     Q_PRIVATE_SLOT( d_ptr, void dataAvailable() )
+    Q_PRIVATE_SLOT( d_ptr, void serverStateChanged( Akonadi::ServerManager::State ) )
 
     friend class ResourceBasePrivate;
     //@endcond
