@@ -17,6 +17,7 @@
 
 #include "setup.h"
 #include "config.h" //krazy:exclude=includes
+#include "dbusconnectionpool.h"
 #include "symbols.h"
 
 #include <kapplication.h>
@@ -191,6 +192,12 @@ void SetupTest::registerWithInternalDBus( const QString &address )
 
 bool SetupTest::startAkonadiDaemon()
 {
+  if ( !mAkonadiDaemonProcess ) {
+    mAkonadiDaemonProcess = new KProcess( this );
+    connect( mAkonadiDaemonProcess, SIGNAL(finished(int)),
+            this, SLOT(slotAkonadiDaemonProcessFinished(int)) );
+  }
+
   mAkonadiDaemonProcess->setProgram( QLatin1String( "akonadi_control" ) );
   mAkonadiDaemonProcess->start();
   const bool started = mAkonadiDaemonProcess->waitForStarted( 5000 );
@@ -198,8 +205,10 @@ bool SetupTest::startAkonadiDaemon()
   return started;
 }
 
-bool SetupTest::stopAkonadiDaemon()
+void SetupTest::stopAkonadiDaemon()
 {
+  if ( !mAkonadiDaemonProcess )
+    return;
   disconnect( mAkonadiDaemonProcess, SIGNAL( finished(int) ), this, 0 );
   mAkonadiDaemonProcess->terminate();
   const bool finished = mAkonadiDaemonProcess->waitForFinished( 5000 );
@@ -207,7 +216,8 @@ bool SetupTest::stopAkonadiDaemon()
     kDebug() << "Problem finishing process.";
   }
   mAkonadiDaemonProcess->close();
-  return finished;
+  mAkonadiDaemonProcess->deleteLater();
+  mAkonadiDaemonProcess = 0;
 }
 
 void SetupTest::setupAgents()
@@ -370,7 +380,8 @@ void SetupTest::cleanTempEnvironment()
 }
 
 SetupTest::SetupTest() :
-  mInternalBus( QDBusConnection::sessionBus() ),
+  mAkonadiDaemonProcess( 0 ),
+  mInternalBus( Akonadi::DBusConnectionPool::threadConnection() ),
   mShuttingDown( false ),
   mSyncMapper( new QSignalMapper( this ) ),
   mAgentsCreated( false ),
@@ -404,17 +415,12 @@ SetupTest::SetupTest() :
   registerWithInternalDBus( dbusAddress );
 #endif
 
-  mAkonadiDaemonProcess = new KProcess( this );
-  connect( mAkonadiDaemonProcess, SIGNAL(finished(int)),
-           this, SLOT(slotAkonadiDaemonProcessFinished(int)));
-
   connect( mSyncMapper, SIGNAL(mapped(QString)), SLOT(resourceSynchronized(QString)) );
 }
 
 SetupTest::~SetupTest()
 {
   cleanTempEnvironment();
-  delete mAkonadiDaemonProcess;
 }
 
 void SetupTest::shutdown()
@@ -430,32 +436,37 @@ void SetupTest::shutdown()
     QDBusReply<void> reply = controlIface.call( "shutdown" );
     if ( !reply.isValid() ) {
       kWarning() << "Failed to shutdown Akonadi control: " << reply.error().message();
+      shutdownKde();
       shutdownHarder();
     } else {
       // safety timeout
       QTimer::singleShot( 30 * 1000, this, SLOT( shutdownHarder() ) );
     }
-
     // in case we indirectly started KDE processes, stop those before we kill their D-Bus
-    if ( mInternalBus.interface()->isServiceRegistered( "org.kde.klauncher" ) ) {
-      QDBusInterface klauncherIface( QLatin1String( "org.kde.klauncher" ), QLatin1String( "/" ),
-                                   QLatin1String( "org.kde.KLauncher" ), mInternalBus );
-      QDBusReply<void> reply = klauncherIface.call( "terminate_kdeinit" );
-      if ( !reply.isValid() )
-        kDebug() << reply.error();
-    }
-    if ( mInternalBus.interface()->isServiceRegistered( "org.kde.kded" ) ) {
-      QDBusInterface klauncherIface( QLatin1String( "org.kde.kded" ), QLatin1String( "/kded" ),
-                                   QLatin1String( "org.kde.kded" ), mInternalBus );
-      QDBusReply<void> reply = klauncherIface.call( "quit" );
-      if ( !reply.isValid() )
-        kDebug() << reply.error();
-    }
+    shutdownKde();
   } else {
     shutdownHarder();
   }
 }
 
+void SetupTest::shutdownKde()
+{
+  if ( mInternalBus.interface()->isServiceRegistered( "org.kde.klauncher" ) ) {
+    QDBusInterface klauncherIface( QLatin1String( "org.kde.klauncher" ), QLatin1String( "/" ),
+                                  QLatin1String( "org.kde.KLauncher" ), mInternalBus );
+    QDBusReply<void> reply = klauncherIface.call( "terminate_kdeinit" );
+    if ( !reply.isValid() )
+      kDebug() << reply.error();
+  }
+  if ( mInternalBus.interface()->isServiceRegistered( "org.kde.kded" ) ) {
+    QDBusInterface klauncherIface( QLatin1String( "org.kde.kded" ), QLatin1String( "/kded" ),
+                                  QLatin1String( "org.kde.kded" ), mInternalBus );
+    QDBusReply<void> reply = klauncherIface.call( "quit" );
+    if ( !reply.isValid() )
+      kDebug() << reply.error();
+  }
+}
+
 void SetupTest::shutdownHarder()
 {
   kDebug();
@@ -474,7 +485,11 @@ void SetupTest::restartAkonadiServer()
   QDBusReply<void> reply = controlIface.call( "shutdown" );
   if ( !reply.isValid() )
     kWarning() << "Failed to shutdown Akonadi control: " << reply.error().message();
-  Q_ASSERT( mAkonadiDaemonProcess->waitForFinished() );
+  const bool shutdownResult = mAkonadiDaemonProcess->waitForFinished();
+  if ( !shutdownResult ) {
+    kWarning() << "Akonadi control did not shut down in time, killing it.";
+    mAkonadiDaemonProcess->kill();
+  }
   // we don't use Control::start() since we want to be able to kill
   // it forcefully, if necessary, and know the pid
   startAkonadiDaemon();
@@ -509,6 +524,7 @@ void SetupTest::slotAkonadiDaemonProcessFinished(int exitCode)
     kWarning() << "Akonadi server process was terminated externally!";
     emit serverExited( exitCode );
   }
+  mAkonadiDaemonProcess = 0;
 }
 
 void SetupTest::trackAkonadiProcess(bool track)
