@@ -38,6 +38,7 @@
 #include "recurrence.h"
 
 #include <QtCore/QList>
+#include <QtCore/QMetaType>
 
 namespace boost {
   template <typename T> class shared_ptr;
@@ -64,7 +65,7 @@ namespace KCal {
   and Incidence contains all additional properties that are common to
   Events, Todos and Journals, but are not allowed for FreeBusy entries.
 */
-class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class templates confuse krazy
+class KCAL_EXPORT_DEPRECATED Incidence //krazy:exclude=dpointer since nested class templates confuse krazy
   : public IncidenceBase, public Recurrence::RecurrenceObserver
 {
   public:
@@ -891,4 +892,7 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
 
 }
 
+#define KCAL_INCIDENCE_METATYPE_DEFINED 1
+Q_DECLARE_METATYPE( KCal::Incidence* )
+
 #endif
