@@ -30,6 +30,7 @@
 #include "event.h"
 #include "journal.h"
 #include "calendar.h"
+#include "exceptions.h"
 
 #include "kresources/resource.h"
 #include "kresources/manager.h"
@@ -46,7 +47,7 @@ namespace KCal {
   This class provides the interfaces for a calendar resource. It makes use of
   the kresources framework.
 */
-class KCAL_EXPORT ResourceCalendar : public KRES::Resource
+class KCAL_EXPORT_DEPRECATED ResourceCalendar : public KRES::Resource
 {
   Q_OBJECT
   public:
@@ -195,13 +196,13 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       date specified. Useful for dayView, etc. etc.
 
       @param date date for which to get the events
-      @param timespec the time specification of the date
+      @param timeSpec the time specification of the date
       @param sortField field used as the sort key for the result list
       @param sortDirection direction of sorting according to @p sortField
     */
     virtual Event::List rawEventsForDate(
       const QDate &date,
-      const KDateTime::Spec &timespec = KDateTime::Spec(),
+      const KDateTime::Spec &timeSpec = KDateTime::Spec(),
       EventSortField sortField = EventSortUnsorted,
       SortDirection sortDirection = SortDirectionAscending ) = 0;
 
@@ -222,7 +223,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     */
     virtual Event::List rawEvents(
       const QDate &start, const QDate &end,
-      const KDateTime::Spec &timespec = KDateTime::Spec(),
+      const KDateTime::Spec &timeSpec = KDateTime::Spec(),
       bool inclusive = false ) = 0;
 
     /**
@@ -538,6 +539,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
   private:
     //@cond PRIVATE
     Q_DISABLE_COPY( ResourceCalendar )
+
     class Private;
     Private *const d;
     //@endcond
