@@ -173,8 +173,10 @@ TextEdit::~TextEdit()
 
 bool TextEdit::eventFilter( QObject*o, QEvent* e )
 {
+#ifndef QT_NO_CURSOR
   if ( o == this )
     KCursor::autoHideEventFilter( o, e );
+#endif
   return KRichTextWidget::eventFilter( o, e );
 }
 
@@ -191,7 +193,9 @@ void TextEditPrivate::init()
   spellCheckingEnabled = false;
   q->setCheckSpellingEnabledInternal( true );
 
+#ifndef QT_NO_CURSOR
   KCursor::setAutoHideCursor( q, true, true );
+#endif
   q->installEventFilter( q );
 }
 
@@ -545,6 +549,11 @@ void KPIMTextEdit::TextEdit::enableImageActions()
   d->imageSupportEnabled = true;
 }
 
+bool KPIMTextEdit::TextEdit::isEnableImageActions() const
+{
+  return d->imageSupportEnabled;
+}
+
 QByteArray KPIMTextEdit::TextEdit::imageNamesToContentIds( const QByteArray &htmlBody, const KPIMTextEdit::ImageList &imageList )
 {
   QByteArray result = htmlBody;
